@@ -557,9 +557,11 @@ def set_gostatus(request):
     except:
         request.session['err'] = ('Next status does not exist',)
         return HttpResponse(return_url)
-    parent_obj_model = cs_obj.get_model()
+    parent_obj_model, attr_name = cs_obj.get_attr_parts()
     parent_obj = parent_obj_model.objects.get(id=parent_obj_id)
-    parent_obj.status = ns_obj
+#    parent_obj.status = ns_obj
+#    cs_obj.set_status(ns_obj)
+    setattr(parent_obj, attr_name, ns_obj)
     parent_obj.save()
     request.session['info'] = ('Status has been updated',)
     return HttpResponseRedirect(return_url)
